# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: index.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='index.proto',
  package='indexing',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\x0bindex.proto\x12\x08indexing\",\n\x0bVectorLabel\x12\x0e\n\x06vector\x18\x01 \x03(\x01\x12\r\n\x05label\x18\x02 \x01(\t\";\n\x0cIndexRequest\x12+\n\x0cvectorLabels\x18\x01 \x03(\x0b\x32\x15.indexing.VectorLabel\"7\n\x0cQueryRequest\x12\x0e\n\x06vector\x18\x01 \x03(\x01\x12\x17\n\x0fnumberOfResults\x18\x02 \x01(\x05\"$\n\x0c\x42uildRequest\x12\x14\n\x0cnumberOfTree\x18\x01 \x01(\x05\"\x1d\n\nBuildReply\x12\x0f\n\x07message\x18\x01 \x01(\t\"\x1d\n\nIndexReply\x12\x0f\n\x07message\x18\x01 \x01(\t\"0\n\x0bQueryResult\x12\r\n\x05label\x18\x01 \x01(\t\x12\x12\n\nsimilarity\x18\x02 \x01(\x01\"9\n\nQueryReply\x12+\n\x0cqueryResults\x18\x01 \x03(\x0b\x32\x15.indexing.QueryResult\"\x14\n\x12HealthCheckRequest\"&\n\x13HealthCheckResponse\x12\x0f\n\x07message\x18\x01 \x01(\t2\xb2\x01\n\x05Index\x12\x37\n\x05index\x12\x16.indexing.IndexRequest\x1a\x14.indexing.IndexReply\"\x00\x12\x37\n\x05\x62uild\x12\x16.indexing.BuildRequest\x1a\x14.indexing.BuildReply\"\x00\x12\x37\n\x05query\x12\x16.indexing.QueryRequest\x1a\x14.indexing.QueryReply\"\x00\x62\x06proto3')
)




_VECTORLABEL = _descriptor.Descriptor(
  name='VectorLabel',
  full_name='indexing.VectorLabel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vector', full_name='indexing.VectorLabel.vector', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='indexing.VectorLabel.label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=25,
  serialized_end=69,
)


_INDEXREQUEST = _descriptor.Descriptor(
  name='IndexRequest',
  full_name='indexing.IndexRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vectorLabels', full_name='indexing.IndexRequest.vectorLabels', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=71,
  serialized_end=130,
)


_QUERYREQUEST = _descriptor.Descriptor(
  name='QueryRequest',
  full_name='indexing.QueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vector', full_name='indexing.QueryRequest.vector', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='numberOfResults', full_name='indexing.QueryRequest.numberOfResults', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=132,
  serialized_end=187,
)


_BUILDREQUEST = _descriptor.Descriptor(
  name='BuildRequest',
  full_name='indexing.BuildRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='numberOfTree', full_name='indexing.BuildRequest.numberOfTree', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=189,
  serialized_end=225,
)


_BUILDREPLY = _descriptor.Descriptor(
  name='BuildReply',
  full_name='indexing.BuildReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='indexing.BuildReply.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=227,
  serialized_end=256,
)


_INDEXREPLY = _descriptor.Descriptor(
  name='IndexReply',
  full_name='indexing.IndexReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='indexing.IndexReply.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=258,
  serialized_end=287,
)


_QUERYRESULT = _descriptor.Descriptor(
  name='QueryResult',
  full_name='indexing.QueryResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='label', full_name='indexing.QueryResult.label', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='similarity', full_name='indexing.QueryResult.similarity', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=289,
  serialized_end=337,
)


_QUERYREPLY = _descriptor.Descriptor(
  name='QueryReply',
  full_name='indexing.QueryReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='queryResults', full_name='indexing.QueryReply.queryResults', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=339,
  serialized_end=396,
)


_HEALTHCHECKREQUEST = _descriptor.Descriptor(
  name='HealthCheckRequest',
  full_name='indexing.HealthCheckRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=398,
  serialized_end=418,
)


_HEALTHCHECKRESPONSE = _descriptor.Descriptor(
  name='HealthCheckResponse',
  full_name='indexing.HealthCheckResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='indexing.HealthCheckResponse.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=420,
  serialized_end=458,
)

_INDEXREQUEST.fields_by_name['vectorLabels'].message_type = _VECTORLABEL
_QUERYREPLY.fields_by_name['queryResults'].message_type = _QUERYRESULT
DESCRIPTOR.message_types_by_name['VectorLabel'] = _VECTORLABEL
DESCRIPTOR.message_types_by_name['IndexRequest'] = _INDEXREQUEST
DESCRIPTOR.message_types_by_name['QueryRequest'] = _QUERYREQUEST
DESCRIPTOR.message_types_by_name['BuildRequest'] = _BUILDREQUEST
DESCRIPTOR.message_types_by_name['BuildReply'] = _BUILDREPLY
DESCRIPTOR.message_types_by_name['IndexReply'] = _INDEXREPLY
DESCRIPTOR.message_types_by_name['QueryResult'] = _QUERYRESULT
DESCRIPTOR.message_types_by_name['QueryReply'] = _QUERYREPLY
DESCRIPTOR.message_types_by_name['HealthCheckRequest'] = _HEALTHCHECKREQUEST
DESCRIPTOR.message_types_by_name['HealthCheckResponse'] = _HEALTHCHECKRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

VectorLabel = _reflection.GeneratedProtocolMessageType('VectorLabel', (_message.Message,), {
  'DESCRIPTOR' : _VECTORLABEL,
  '__module__' : 'index_pb2'
  # @@protoc_insertion_point(class_scope:indexing.VectorLabel)
  })
_sym_db.RegisterMessage(VectorLabel)

IndexRequest = _reflection.GeneratedProtocolMessageType('IndexRequest', (_message.Message,), {
  'DESCRIPTOR' : _INDEXREQUEST,
  '__module__' : 'index_pb2'
  # @@protoc_insertion_point(class_scope:indexing.IndexRequest)
  })
_sym_db.RegisterMessage(IndexRequest)

QueryRequest = _reflection.GeneratedProtocolMessageType('QueryRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREQUEST,
  '__module__' : 'index_pb2'
  # @@protoc_insertion_point(class_scope:indexing.QueryRequest)
  })
_sym_db.RegisterMessage(QueryRequest)

BuildRequest = _reflection.GeneratedProtocolMessageType('BuildRequest', (_message.Message,), {
  'DESCRIPTOR' : _BUILDREQUEST,
  '__module__' : 'index_pb2'
  # @@protoc_insertion_point(class_scope:indexing.BuildRequest)
  })
_sym_db.RegisterMessage(BuildRequest)

BuildReply = _reflection.GeneratedProtocolMessageType('BuildReply', (_message.Message,), {
  'DESCRIPTOR' : _BUILDREPLY,
  '__module__' : 'index_pb2'
  # @@protoc_insertion_point(class_scope:indexing.BuildReply)
  })
_sym_db.RegisterMessage(BuildReply)

IndexReply = _reflection.GeneratedProtocolMessageType('IndexReply', (_message.Message,), {
  'DESCRIPTOR' : _INDEXREPLY,
  '__module__' : 'index_pb2'
  # @@protoc_insertion_point(class_scope:indexing.IndexReply)
  })
_sym_db.RegisterMessage(IndexReply)

QueryResult = _reflection.GeneratedProtocolMessageType('QueryResult', (_message.Message,), {
  'DESCRIPTOR' : _QUERYRESULT,
  '__module__' : 'index_pb2'
  # @@protoc_insertion_point(class_scope:indexing.QueryResult)
  })
_sym_db.RegisterMessage(QueryResult)

QueryReply = _reflection.GeneratedProtocolMessageType('QueryReply', (_message.Message,), {
  'DESCRIPTOR' : _QUERYREPLY,
  '__module__' : 'index_pb2'
  # @@protoc_insertion_point(class_scope:indexing.QueryReply)
  })
_sym_db.RegisterMessage(QueryReply)

HealthCheckRequest = _reflection.GeneratedProtocolMessageType('HealthCheckRequest', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKREQUEST,
  '__module__' : 'index_pb2'
  # @@protoc_insertion_point(class_scope:indexing.HealthCheckRequest)
  })
_sym_db.RegisterMessage(HealthCheckRequest)

HealthCheckResponse = _reflection.GeneratedProtocolMessageType('HealthCheckResponse', (_message.Message,), {
  'DESCRIPTOR' : _HEALTHCHECKRESPONSE,
  '__module__' : 'index_pb2'
  # @@protoc_insertion_point(class_scope:indexing.HealthCheckResponse)
  })
_sym_db.RegisterMessage(HealthCheckResponse)



_INDEX = _descriptor.ServiceDescriptor(
  name='Index',
  full_name='indexing.Index',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=461,
  serialized_end=639,
  methods=[
  _descriptor.MethodDescriptor(
    name='index',
    full_name='indexing.Index.index',
    index=0,
    containing_service=None,
    input_type=_INDEXREQUEST,
    output_type=_INDEXREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='build',
    full_name='indexing.Index.build',
    index=1,
    containing_service=None,
    input_type=_BUILDREQUEST,
    output_type=_BUILDREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='query',
    full_name='indexing.Index.query',
    index=2,
    containing_service=None,
    input_type=_QUERYREQUEST,
    output_type=_QUERYREPLY,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_INDEX)

DESCRIPTOR.services_by_name['Index'] = _INDEX

# @@protoc_insertion_point(module_scope)
